/**
 * @file JavaScript library for declension of Ukrainian anthroponyms
 * @module shevchenko
 * @version 3.1.4
 * @author Oleksandr Tolochko <shevchenko-js@tooleks.com>
 * @license MIT
 * @copyright 2017-2025 Oleksandr Tolochko <shevchenko-js@tooleks.com>
 * @see {@link git+https://github.com/tooleks/shevchenko-js.git}
 */
'use strict';

var bootstrap = require('../word-declension/bootstrap.js');
var anthroponymInflector$1 = require('./anthroponym-inflector.js');
var familyNameClassifer = require('./family-name-classifier/family-name-classifer.js');
var modelBundleLoader = require('./family-name-classifier/model-bundle-loader.js');
var familyNameInflector$1 = require('./family-name-inflector.js');
var givenNameInflector$1 = require('./given-name-inflector.js');
var patronymicNameInflector$1 = require('./patronymic-name-inflector.js');

const givenNameInflector = new givenNameInflector$1.GivenNameInflector(bootstrap.wordInflector);
const patronymicNameInflector = new patronymicNameInflector$1.PatronymicNameInflector(bootstrap.wordInflector);
const familyNameClassifier = new familyNameClassifer.FamilyNameClassifier(new modelBundleLoader.ModelBundleLoader());
const familyNameInflector = new familyNameInflector$1.FamilyNameInflector(bootstrap.wordInflector, familyNameClassifier);
const anthroponymInflector = new anthroponymInflector$1.AnthroponymInflector(givenNameInflector, patronymicNameInflector, familyNameInflector);

exports.anthroponymInflector = anthroponymInflector;
