/**
 * @file JavaScript library for declension of Ukrainian anthroponyms
 * @module shevchenko
 * @version 3.1.4
 * @author Oleksandr Tolochko <shevchenko-js@tooleks.com>
 * @license MIT
 * @copyright 2017-2025 Oleksandr Tolochko <shevchenko-js@tooleks.com>
 * @see {@link git+https://github.com/tooleks/shevchenko-js.git}
 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var incorrectPredictionsCache = {
	"штих": "noun",
	"пяних": "noun",
	"белих": "adjective",
	"борзих": "adjective",
	"малих": "adjective",
	"старих": "adjective",
	"дарнопих": "noun",
	"сухих": "adjective",
	"черемних": "noun",
	"сирих": "adjective",
	"плохих": "adjective",
	"целих": "adjective",
	"жих": "noun",
	"войцих": "noun",
	"скорих": "adjective",
	"бурих": "adjective",
	"чалих": "adjective",
	"серих": "adjective",
	"удалих": "adjective",
	"карих": "adjective",
	"гених": "noun",
	"литвих": "noun",
	"марцих": "noun",
	"сізих": "adjective",
	"яних": "noun",
	"мжачих": "adjective",
	"сірих": "adjective",
	"янбих": "noun",
	"бодрих": "adjective",
	"стрий": "noun",
	"чорторий": "noun",
	"юрий": "adjective",
	"цибрий": "noun",
	"цібрий": "noun",
	"карий": "adjective",
	"куприй": "noun",
	"кирий": "noun",
	"негрий": "noun",
	"губрий": "noun",
	"шкабрий": "noun",
	"замрий": "noun",
	"передрий": "noun",
	"одерий": "noun",
	"жегрий": "noun",
	"жарий": "adjective",
	"зюбрий": "noun",
	"семерий": "noun",
	"лий": "noun",
	"бий": "noun",
	"рий": "noun",
	"вий": "noun",
	"ший": "noun",
	"валий": "noun",
	"крайній": "adjective",
	"осінній": "adjective",
	"кутній": "adjective",
	"середній": "adjective",
	"горішній": "adjective",
	"безродній": "adjective",
	"осадчій": "adjective",
	"кий": "noun",
	"новохатній": "adjective",
	"очеретній": "adjective",
	"рбий": "noun",
	"закутній": "adjective",
	"недавній": "adjective",
	"порожній": "adjective",
	"бокий": "noun",
	"вчерашній": "adjective",
	"огородній": "adjective",
	"трощий": "noun",
	"вчорашній": "adjective",
	"житній": "adjective",
	"нижній": "adjective",
	"синій": "adjective",
	"хорий": "noun",
	"краснобокій": "adjective",
	"хижній": "adjective",
	"забродній": "adjective",
	"калюжній": "adjective",
	"виноградній": "adjective",
	"коломий": "noun",
	"летучій": "adjective",
	"поздній": "adjective",
	"серий": "noun",
	"нагорній": "adjective",
	"фартушній": "adjective",
	"холошвій": "noun",
	"батий": "noun",
	"волошиній": "adjective",
	"жирий": "noun",
	"заможній": "adjective",
	"короткій": "adjective",
	"останній": "adjective",
	"передній": "adjective",
	"піддубній": "adjective",
	"пізній": "adjective",
	"погородній": "adjective",
	"бояжній": "adjective",
	"смий": "noun",
	"задвірній": "adjective",
	"остатній": "adjective",
	"підсадній": "adjective",
	"достатній": "adjective",
	"зимній": "adjective",
	"рябой": "adjective",
	"рудой": "adjective",
	"козодой": "noun",
	"яровой": "adjective",
	"кривой": "adjective",
	"садовой": "adjective",
	"полевой": "adjective",
	"сисой": "noun",
	"плохой": "adjective",
	"сухой": "adjective",
	"гаєвой": "adjective",
	"глухой": "adjective",
	"горевой": "adjective",
	"кутовой": "adjective",
	"копаной": "adjective",
	"злой": "adjective",
	"сєдой": "adjective",
	"благой": "adjective",
	"водостой": "noun",
	"косой": "adjective",
	"ліждвой": "noun",
	"большой": "adjective",
	"половой": "adjective",
	"чорной": "adjective",
	"косогой": "adjective",
	"золотой": "adjective",
	"лановой": "adjective",
	"яловой": "adjective",
	"дорогой": "adjective",
	"німой": "adjective",
	"первой": "adjective",
	"русой": "adjective",
	"худой": "adjective",
	"цаподой": "noun",
	"авасілой": "noun",
	"валовой": "adjective",
	"гнідой": "adjective",
	"молокопой": "noun",
	"золотобой": "noun",
	"ярковой": "noun",
	"аміхалакіой": "noun",
	"седой": "adjective",
	"крутой": "adjective",
	"кучной": "adjective",
	"слепой": "adjective",
	"дурной": "adjective",
	"молодой": "adjective",
	"бухой": "adjective",
	"самотній": "adjective",
	"біла": "adjective",
	"бура": "adjective",
	"велика": "adjective",
	"домовина": "noun",
	"рослина": "noun",
	"врецьона": "noun",
	"глибока": "adjective",
	"висока": "adjective",
	"гладка": "adjective",
	"грицина": "noun",
	"гужва": "noun",
	"ковінька": "noun",
	"дика": "adjective",
	"діброва": "noun",
	"кицька": "noun",
	"ківа": "noun",
	"лепка": "adjective",
	"островерха": "adjective",
	"петрина": "noun",
	"прудка": "adjective",
	"семенина": "noun",
	"турчина": "noun",
	"чуприна": "noun",
	"швидка": "adjective",
	"щербина": "noun",
	"яковина": "noun",
	"синьоока": "adjective",
	"крива": "adjective",
	"сліпа": "adjective",
	"глуха": "adjective",
	"жовта": "adjective",
	"добра": "adjective",
	"хоробра": "adjective",
	"сухоребра": "adjective",
	"гарна": "adjective",
	"мала": "adjective",
	"весна": "noun",
	"зла": "adjective",
	"жива": "adjective",
	"ніяка": "adjective",
	"ціла": "adjective",
	"молода": "adjective",
	"далека": "adjective",
	"золота": "adjective",
	"жвава": "adjective",
	"дорога": "adjective",
	"коса": "adjective",
	"литва": "noun",
	"чужа": "adjective",
	"тепла": "adjective",
	"груба": "adjective",
	"слава": "noun",
	"брова": "noun",
	"стара": "adjective",
	"катерина": "noun",
	"василина": "noun",
	"нижня": "adjective",
	"худа": "adjective",
	"проста": "adjective",
	"дівоча": "adjective",
	"крута": "adjective",
	"метка": "adjective",
	"чорна": "adjective",
	"сторона": "noun",
	"невкрита": "adjective",
	"руда": "adjective",
	"темна": "adjective",
	"проява": "noun",
	"тиха": "adjective",
	"божа": "adjective",
	"весела": "adjective",
	"бабина": "adjective",
	"суха": "adjective",
	"люта": "adjective",
	"стіна": "noun",
	"вража": "adjective",
	"хороша": "adjective",
	"легка": "adjective",
	"козача": "adjective",
	"польща": "noun",
	"недужа": "adjective",
	"розлога": "adjective",
	"гаряча": "adjective",
	"середня": "adjective",
	"торішня": "adjective",
	"сита": "adjective",
	"гостра": "adjective",
	"осіння": "adjective",
	"невесела": "adjective",
	"москва": "noun",
	"широка": "adjective",
	"половина": "noun",
	"синя": "adjective",
	"сира": "adjective",
	"довга": "adjective",
	"коротка": "adjective",
	"лукава": "adjective",
	"абияка": "adjective",
	"королева": "noun",
	"чайна": "adjective",
	"сіра": "adjective",
	"сутула": "adjective",
	"сава": "noun",
	"дебела": "adjective",
	"мокра": "adjective",
	"убога": "adjective",
	"безрука": "adjective",
	"димна": "adjective",
	"мила": "adjective",
	"боса": "adjective",
	"гола": "adjective",
	"красноока": "adjective",
	"остання": "adjective",
	"десна": "noun",
	"житня": "adjective",
	"тризна": "noun",
	"цупка": "adjective",
	"порожня": "adjective",
	"ліва": "adjective",
	"сьома": "adjective",
	"вовна": "noun",
	"сова": "noun",
	"бела": "adjective",
	"ряба": "adjective",
	"гніда": "adjective",
	"гожа": "adjective",
	"кисла": "adjective",
	"кутня": "adjective",
	"огниста": "adjective",
	"мудра": "adjective",
	"дужа": "adjective",
	"підстава": "noun",
	"бодра": "adjective",
	"бадьора": "adjective",
	"кривохижа": "adjective",
	"прихожа": "adjective",
	"побожа": "adjective",
	"пригожа": "adjective",
	"петрунька": "noun",
	"ковинька": "noun",
	"кишинька": "noun",
	"кропивянька": "noun",
	"зеленька": "noun",
	"лабунька": "noun",
	"м'якенька": "adjective",
	"бухонька": "noun",
	"сиза": "adjective",
	"маза": "adjective",
	"блаза": "adjective",
	"улина": "adjective",
	"ейвена": "adjective",
	"еремина": "adjective",
	"ена": "adjective",
	"клята": "adjective",
	"периста": "adjective",
	"працевита": "adjective",
	"свіжа": "adjective",
	"рижа": "adjective",
	"копистира": "noun",
	"скорина": "noun",
	"більченя": "noun",
	"кривошеня": "noun",
	"нестереня": "noun",
	"захарченя": "noun",
	"войценя": "noun",
	"протасеня": "noun",
	"олещеня": "noun",
	"денисеня": "noun",
	"стрельченя": "noun",
	"молодоженя": "noun",
	"заграва": "noun",
	"неменша": "adjective",
	"неменьша": "adjective",
	"меньша": "adjective",
	"паший": "noun",
	"пєша": "adjective",
	"дзвінка": "adjective",
	"пухка": "adjective",
	"безпала": "adjective",
	"вобла": "adjective",
	"горжа": "adjective",
	"горіла": "adjective",
	"китаста": "adjective",
	"лиса": "adjective",
	"осадча": "adjective",
	"пелехата": "adjective",
	"підпала": "adjective",
	"ставнича": "adjective",
	"чала": "adjective",
	"чубата": "adjective",
	"целомудра": "adjective",
	"кара": "adjective",
	"коцупатра": "adjective",
	"немудра": "adjective",
	"шара": "adjective",
	"шингира": "adjective",
	"передера": "adjective",
	"далекора": "adjective",
	"жара": "adjective",
	"яра": "adjective",
	"золотопера": "adjective",
	"остра": "adjective",
	"хитра": "adjective",
	"прозора": "adjective",
	"карчинска": "adjective",
	"гнила": "adjective",
	"хижа": "adjective",
	"крижа": "adjective",
	"погоріла": "adjective",
	"куца": "adjective",
	"солодка": "adjective",
	"безверха": "adjective",
	"усата": "adjective",
	"довгопола": "adjective",
	"щербата": "adjective",
	"пишна": "adjective",
	"хоружа": "adjective",
	"мирна": "adjective",
	"долга": "adjective",
	"бєла": "adjective",
	"надточа": "adjective",
	"гаркава": "adjective",
	"мягка": "adjective",
	"топча": "adjective",
	"товста": "adjective",
	"блага": "adjective",
	"захожа": "adjective",
	"боліла": "adjective",
	"басиста": "adjective",
	"басіста": "adjective",
	"люба": "adjective",
	"горбата": "adjective",
	"драна": "adjective",
	"куряча": "adjective",
	"куса": "adjective",
	"зайва": "adjective",
	"кругла": "adjective",
	"брижата": "adjective",
	"скора": "adjective",
	"плоха": "adjective",
	"горяча": "adjective",
	"тверда": "adjective",
	"невідома": "adjective",
	"картава": "adjective",
	"горна": "adjective",
	"черна": "adjective",
	"гуржа": "adjective",
	"гикава": "adjective",
	"шита": "adjective",
	"сєра": "adjective",
	"сіда": "adjective",
	"гнуча": "adjective",
	"слизька": "adjective",
	"бистра": "adjective",
	"полева": "adjective",
	"парубоча": "adjective",
	"вібла": "adjective",
	"мазна": "adjective",
	"волохата": "adjective",
	"шалена": "adjective",
	"щира": "adjective",
	"слаба": "adjective",
	"суковата": "adjective",
	"нища": "adjective",
	"одинока": "adjective",
	"сядриста": "adjective",
	"яшна": "adjective",
	"ракоча": "adjective",
	"губата": "adjective",
	"летуча": "adjective",
	"патлата": "adjective",
	"вяла": "adjective",
	"гірна": "adjective",
	"кіптіла": "adjective",
	"кривовяза": "adjective",
	"лиха": "adjective",
	"подуфала": "adjective",
	"буйна": "adjective",
	"зайшла": "adjective",
	"купрата": "adjective",
	"мерзла": "adjective",
	"варгата": "adjective",
	"горда": "adjective",
	"драпата": "adjective",
	"загризла": "adjective",
	"кичата": "adjective",
	"оковита": "adjective",
	"тлуста": "adjective",
	"тонка": "adjective",
	"коптіла": "adjective",
	"погожа": "adjective",
	"товстокора": "adjective",
	"гладенька": "adjective",
	"глубока": "adjective",
	"періста": "adjective",
	"виконавча": "adjective",
	"кохана": "adjective",
	"кризька": "adjective",
	"німа": "adjective",
	"росла": "adjective",
	"некипіла": "adjective",
	"плакуща": "adjective",
	"похила": "adjective",
	"строга": "adjective",
	"богата": "adjective",
	"заливча": "adjective",
	"крамна": "adjective",
	"поставнича": "adjective",
	"безуса": "adjective",
	"плоска": "adjective",
	"сергата": "adjective",
	"сухотепла": "adjective",
	"толста": "adjective",
	"шарпата": "adjective",
	"безребра": "adjective",
	"душна": "adjective",
	"змерзла": "adjective",
	"золотоверха": "adjective",
	"наточа": "adjective",
	"положа": "adjective",
	"рокоча": "adjective",
	"горлата": "adjective",
	"скупа": "adjective",
	"бібла": "adjective",
	"ільніцка": "adjective",
	"рогоча": "adjective",
	"сміла": "adjective",
	"щедра": "adjective",
	"безклуба": "adjective",
	"білоока": "adjective",
	"шерстка": "adjective",
	"безкишка": "adjective",
	"летюча": "adjective",
	"ловча": "adjective",
	"піша": "adjective",
	"раба": "adjective",
	"суховерха": "adjective",
	"тягла": "adjective",
	"шаблиста": "adjective",
	"шубала": "adjective",
	"бедрата": "adjective",
	"верлата": "adjective",
	"галича": "adjective",
	"запухла": "adjective",
	"зубата": "adjective",
	"кунта": "adjective",
	"некрита": "adjective",
	"пахуча": "adjective",
	"теляча": "adjective",
	"шпарка": "adjective",
	"глива": "adjective",
	"косата": "adjective",
	"любима": "adjective",
	"низька": "adjective",
	"окрепка": "adjective",
	"робоча": "adjective",
	"слизькоуха": "adjective",
	"хропата": "adjective",
	"цівата": "adjective",
	"шията": "adjective",
	"безборода": "adjective",
	"голоборода": "adjective",
	"голомоза": "adjective",
	"горєла": "adjective",
	"єжела": "adjective",
	"калиста": "adjective",
	"корчиста": "adjective",
	"курна": "adjective",
	"надута": "adjective",
	"пікуща": "adjective",
	"погорела": "adjective",
	"савіцка": "adjective",
	"тупа": "adjective",
	"дзяна": "adjective",
	"жовкла": "adjective",
	"колюча": "adjective",
	"мазана": "adjective",
	"сапата": "adjective",
	"світа": "adjective",
	"сухолитка": "adjective",
	"цаберяба": "adjective",
	"цвіла": "adjective",
	"чупла": "adjective",
	"асадча": "adjective",
	"гарагата": "adjective",
	"дзюбата": "adjective",
	"долгопола": "adjective",
	"жилава": "adjective",
	"козина": "adjective",
	"крепка": "adjective",
	"ласа": "adjective",
	"личката": "adjective",
	"лобата": "adjective",
	"льогка": "adjective",
	"мишаста": "adjective",
	"невмита": "adjective",
	"перката": "adjective",
	"рідка": "adjective",
	"саплива": "adjective",
	"тонкошкура": "adjective",
	"цепла": "adjective",
	"беззуба": "adjective",
	"бушна": "adjective",
	"бяла": "adjective",
	"кріпка": "adjective",
	"лакома": "adjective",
	"майна": "adjective",
	"нагла": "adjective",
	"огніста": "adjective",
	"осядла": "adjective",
	"рабоча": "adjective",
	"рапава": "adjective",
	"розмаїта": "adjective",
	"тупча": "adjective",
	"ушата": "adjective",
	"чорноока": "adjective",
	"галянта": "adjective",
	"голомовза": "adjective",
	"одажа": "adjective",
	"орлата": "adjective",
	"пашиста": "adjective",
	"пробита": "adjective",
	"сепіта": "adjective",
	"слабка": "adjective",
	"цікава": "adjective",
	"шамка": "adjective",
	"шибиста": "adjective",
	"баліцка": "adjective",
	"бита": "adjective",
	"боляча": "adjective",
	"глабчаста": "adjective",
	"гусліста": "adjective",
	"деньдобра": "adjective",
	"замліла": "adjective",
	"лабата": "adjective",
	"мяка": "adjective",
	"несміла": "adjective",
	"нєма": "adjective",
	"обща": "adjective",
	"одайна": "adjective",
	"оката": "adjective",
	"остиста": "adjective",
	"пахуща": "adjective",
	"пстра": "adjective",
	"сладка": "adjective",
	"храпата": "adjective",
	"чесніша": "adjective",
	"чула": "adjective",
	"бідноша": "adjective",
	"довгорука": "adjective",
	"довгоша": "adjective",
	"іваніцка": "adjective",
	"корната": "adjective",
	"кулява": "adjective",
	"літуча": "adjective",
	"марна": "adjective",
	"медзата": "adjective",
	"обмокла": "adjective",
	"піджара": "adjective",
	"побоча": "adjective",
	"сагата": "adjective",
	"удала": "adjective",
	"усяка": "adjective",
	"байдужа": "adjective",
	"бескорса": "adjective",
	"гірка": "adjective",
	"главата": "adjective",
	"горча": "adjective",
	"горька": "adjective",
	"добровольска": "adjective",
	"довгопта": "adjective",
	"досужа": "adjective",
	"драпята": "adjective",
	"камяна": "adjective",
	"каправа": "adjective",
	"киричата": "adjective",
	"колота": "adjective",
	"комарніцка": "adjective",
	"люзна": "adjective",
	"молодша": "adjective",
	"неумита": "adjective",
	"пересідла": "adjective",
	"підла": "adjective",
	"пухла": "adjective",
	"семяниста": "adjective",
	"сіроока": "adjective",
	"стряпча": "adjective",
	"твереза": "adjective",
	"цибульска": "adjective",
	"чарна": "adjective",
	"ярка": "adjective",
	"безгуба": "adjective",
	"білоборода": "adjective",
	"болєла": "adjective",
	"бровата": "adjective",
	"гікава": "adjective",
	"голобока": "adjective",
	"драбата": "adjective",
	"жарка": "adjective",
	"каплата": "adjective",
	"кісла": "adjective",
	"ковалевска": "adjective",
	"ковальска": "adjective",
	"козловска": "adjective",
	"крилата": "adjective",
	"куцка": "adjective",
	"малоока": "adjective",
	"мгка": "adjective",
	"немята": "adjective",
	"непроста": "adjective",
	"нехороша": "adjective",
	"пелихата": "adjective",
	"підласа": "adjective",
	"подпала": "adjective",
	"руцка": "adjective",
	"семениста": "adjective",
	"услиста": "adjective",
	"шорстка": "adjective",
	"хила": "adjective",
	"буката": "adjective",
	"васалата": "adjective",
	"вибла": "adjective",
	"видойна": "adjective",
	"виловата": "adjective",
	"гарча": "adjective",
	"горела": "adjective",
	"дута": "adjective",
	"зибла": "adjective",
	"індича": "adjective",
	"кальноока": "adjective",
	"карнауха": "adjective",
	"кривобедра": "adjective",
	"кричфалуша": "adjective",
	"кубата": "adjective",
	"кужда": "adjective",
	"ломана": "adjective",
	"мацевита": "adjective",
	"івашина": "noun",
	"солоха": "adjective",
	"перерва": "noun",
	"проскура": "adjective",
	"бова": "noun",
	"сметана": "noun",
	"дуброва": "noun",
	"проскурня": "noun",
	"родіна": "noun",
	"єна": "noun",
	"солонина": "noun",
	"ліщина": "noun",
	"лугина": "adjective",
	"сосна": "noun",
	"гавва": "noun",
	"ужва": "noun",
	"кулина": "adjective",
	"халява": "noun",
	"холява": "noun",
	"підкова": "noun",
	"крайня": "adjective",
	"хохотва": "noun",
	"цибулька": "noun",
	"нікульча": "noun",
	"кравчина": "noun",
	"лупина": "adjective",
	"лихошва": "noun",
	"думбрава": "noun",
	"плахотня": "adjective",
	"покутня": "adjective",
	"пона": "noun",
	"семена": "noun",
	"грона": "noun",
	"єва": "noun",
	"парасківа": "noun",
	"шова": "noun",
	"бурдужа": "adjective",
	"козюберда": "adjective",
	"говтва": "noun",
	"приколота": "adjective",
	"варнава": "noun",
	"гурина": "adjective",
	"рябокобила": "noun",
	"кучина": "adjective",
	"савва": "noun",
	"кремена": "noun",
	"малая": "adjective",
	"горішня": "adjective",
	"бурдюжа": "adjective",
	"слаква": "noun",
	"городня": "adjective",
	"лиштва": "noun",
	"цяцька": "noun",
	"походня": "noun",
	"недавня": "adjective",
	"долішня": "adjective",
	"марюхна": "noun",
	"борона": "noun",
	"колошва": "noun",
	"семенча": "noun",
	"затона": "noun",
	"заплава": "noun",
	"краснопера": "adjective",
	"рибитва": "noun",
	"сидора": "adjective",
	"краплина": "noun",
	"крутиголова": "noun",
	"бакалина": "adjective",
	"немна": "noun",
	"очеретня": "adjective",
	"пробийголова": "noun",
	"мальона": "noun",
	"сажина": "adjective",
	"вчерашня": "adjective",
	"бузина": "noun",
	"забийворота": "noun",
	"магльона": "noun",
	"нейчева": "noun",
	"потороча": "noun",
	"ревіна": "noun",
	"матьора": "adjective",
	"святина": "noun",
	"хіна": "noun",
	"кожина": "adjective",
	"наріжня": "noun",
	"леона": "noun",
	"передня": "adjective",
	"савина": "adjective",
	"сікачина": "noun",
	"кльова": "noun",
	"недолуга": "adjective",
	"шкоропата": "noun",
	"карасава": "noun",
	"морева": "adjective",
	"мустафіна": "noun",
	"цьова": "noun",
	"бубна": "noun",
	"катона": "noun",
	"міна": "noun",
	"похвала": "noun",
	"слоква": "noun",
	"статіва": "noun",
	"строна": "noun",
	"вова": "noun",
	"карева": "adjective",
	"місюна": "noun",
	"швая": "noun",
	"бальва": "noun",
	"вершина": "noun",
	"врона": "noun",
	"білокобила": "noun",
	"гордина": "noun",
	"кольва": "noun",
	"льова": "noun",
	"перекліта": "noun",
	"основа": "noun",
	"харена": "noun",
	"борозна": "noun",
	"будаква": "noun",
	"каранікола": "noun",
	"палесіка": "noun",
	"рожина": "noun",
	"штана": "noun",
	"вицина": "noun",
	"дубна": "noun",
	"жовна": "noun",
	"зіва": "noun",
	"катарина": "noun",
	"похмура": "adjective",
	"фесина": "noun",
	"шемена": "noun",
	"галутва": "noun",
	"зарева": "noun",
	"ковальва": "noun",
	"мирона": "noun",
	"новосела": "noun",
	"пачина": "adjective",
	"совва": "noun",
	"гіна": "noun",
	"корона": "noun",
	"новоженя": "noun",
	"підберезня": "adjective",
	"ряднина": "noun",
	"сакська": "noun",
	"канна": "noun",
	"лукачина": "noun",
	"плачінта": "noun",
	"редьква": "noun",
	"софина": "adjective",
	"шатня": "adjective",
	"блозва": "noun",
	"вчорашня": "adjective",
	"гриценя": "noun",
	"куропатва": "noun",
	"людва": "noun",
	"стехна": "noun",
	"парахоня": "noun",
	"плєва": "noun",
	"яворина": "noun",
	"бендина": "noun",
	"жовтонога": "adjective",
	"конева": "adjective",
	"мандалина": "noun",
	"мацина": "noun",
	"перезва": "noun",
	"похвата": "noun",
	"токмина": "noun",
	"тюрина": "adjective",
	"гицина": "noun",
	"дзіна": "noun",
	"куява": "noun",
	"малонога": "adjective",
	"стоколоса": "adjective",
	"тимина": "adjective",
	"біднина": "noun",
	"вдовина": "adjective",
	"лисохмара": "noun",
	"микитина": "adjective",
	"полівара": "noun",
	"рибонька": "noun",
	"ружина": "noun",
	"тишина": "noun",
	"цюрмаста": "noun",
	"чалая": "adjective",
	"васина": "noun",
	"воїна": "noun",
	"гулая": "noun",
	"кова": "noun",
	"она": "noun",
	"палісіка": "noun",
	"підошва": "noun",
	"свидина": "noun",
	"тирсина": "noun",
	"хаврона": "noun",
	"зона": "noun",
	"кнзєва": "noun",
	"розна": "adjective",
	"ронжина": "noun",
	"рудомина": "noun",
	"сальва": "noun",
	"скільсара": "noun",
	"служала": "noun",
	"фомина": "adjective",
	"чупина": "adjective",
	"шалупня": "noun",
	"джупина": "noun",
	"зоська": "noun",
	"кузява": "noun",
	"неледва": "noun",
	"равва": "noun",
	"разьва": "noun",
	"шкорина": "noun",
	"білозора": "adjective",
	"бранціра": "noun",
	"випна": "noun",
	"галина": "adjective",
	"мандаліна": "noun",
	"мицька": "noun",
	"мячина": "adjective",
	"недосєка": "noun",
	"пристая": "noun",
	"м'яка": "adjective",
	"вовчина": "noun",
	"гринява": "noun",
	"дівонька": "noun",
	"ігіна": "noun",
	"обійдихата": "noun",
	"хижня": "adjective",
	"челядина": "noun",
	"янева": "adjective",
	"голева": "adjective",
	"дзюнька": "noun",
	"дубрава": "noun",
	"лигомина": "noun",
	"мална": "noun",
	"мархева": "noun",
	"несправа": "noun",
	"озява": "noun",
	"панна": "noun",
	"пупена": "noun",
	"силява": "noun",
	"сухокобила": "noun",
	"цюрмоста": "noun",
	"чевельча": "noun",
	"чівільча": "noun",
	"башева": "noun",
	"бражна": "noun",
	"варавва": "noun",
	"волна": "noun",
	"гольча": "noun",
	"густа": "adjective",
	"достатня": "adjective",
	"зуграва": "noun",
	"карапулька": "noun",
	"кірна": "adjective",
	"крапіва": "noun",
	"луковина": "noun",
	"мамона": "noun",
	"мелещеня": "noun",
	"мряна": "noun",
	"параскева": "noun",
	"похідня": "noun",
	"пріхна": "noun",
	"свтина": "noun",
	"сьоська": "noun",
	"терепіща": "noun",
	"ціцяла": "noun",
	"бодаква": "noun",
	"гальвіта": "noun",
	"деревенча": "noun",
	"дона": "noun",
	"дубена": "noun",
	"задависвічка": "noun",
	"йовва": "noun",
	"капаціла": "noun",
	"котельва": "noun",
	"лісота": "noun",
	"малюська": "noun",
	"підсадня": "adjective",
	"рєва": "noun",
	"сувора": "adjective",
	"хаджава": "noun",
	"хомина": "adjective",
	"псина": "noun",
	"бобина": "noun",
	"болотня": "adjective",
	"бруква": "noun",
	"кіона": "noun",
	"ковбінька": "noun",
	"кривонога": "adjective",
	"лєва": "noun",
	"мухина": "adjective",
	"нефортуна": "noun",
	"органіста": "noun",
	"пасулька": "noun",
	"пристава": "noun",
	"бачина": "noun",
	"безкорса": "adjective",
	"бєлокобила": "noun",
	"борзина": "noun",
	"бружина": "noun",
	"воротня": "adjective",
	"гальона": "noun",
	"голтва": "noun",
	"горемульта": "noun",
	"дацина": "noun",
	"забанджала": "noun",
	"злая": "adjective",
	"кікена": "noun",
	"коропатва": "noun",
	"кузина": "adjective",
	"лапунька": "noun",
	"літава": "noun",
	"мінчуна": "noun",
	"на": "noun",
	"ничая": "noun",
	"новіцка": "adjective",
	"пенькна": "noun",
	"пухна": "noun",
	"пуцята": "noun",
	"рісна": "noun",
	"розмаіта": "noun",
	"румина": "adjective",
	"свтна": "noun",
	"сердита": "adjective",
	"січінава": "noun",
	"сментина": "noun",
	"трізна": "noun",
	"шкуропата": "noun",
	"безхутра": "adjective",
	"гальва": "noun",
	"гнєда": "adjective",
	"гребенча": "noun",
	"гусонька": "noun",
	"калабанька": "noun",
	"козупляка": "noun",
	"лапина": "adjective",
	"мурина": "adjective",
	"некульча": "noun",
	"орона": "noun",
	"парна": "adjective",
	"пліва": "noun",
	"приходька": "noun",
	"сенина": "noun",
	"солотва": "noun",
	"тетева": "adjective",
	"хавана": "noun",
	"царева": "adjective",
	"ахалая": "noun",
	"варенька": "noun",
	"варшава": "noun",
	"вересоча": "noun",
	"галунька": "noun",
	"гліва": "noun",
	"голина": "adjective",
	"грузька": "adjective",
	"гудина": "noun",
	"євона": "noun",
	"кірева": "adjective",
	"кожем'яка": "noun",
	"колоберда": "adjective",
	"курінька": "noun",
	"маржина": "noun",
	"мигалина": "noun",
	"мікава": "adjective",
	"падва": "noun",
	"паланичка": "adjective",
	"палена": "adjective",
	"подкова": "noun",
	"ратушня": "adjective",
	"селегейна": "noun",
	"сминтина": "noun",
	"сумина": "adjective",
	"теміркая": "noun",
	"ухата": "adjective",
	"хавроня": "noun",
	"холоста": "adjective",
	"ціва": "noun",
	"чернята": "noun",
	"чикольва": "noun",
	"шалина": "adjective",
	"юдина": "adjective",
	"адвена": "noun",
	"балева": "adjective",
	"брона": "noun",
	"вербовата": "adjective",
	"веремєва": "noun",
	"волчаста": "adjective",
	"гафина": "adjective",
	"голутва": "noun",
	"закрева": "noun",
	"каджая": "noun",
	"кальченя": "noun",
	"капаниста": "adjective",
	"кикина": "adjective",
	"костерева": "noun",
	"кривокобила": "noun",
	"кулєва": "noun",
	"лавна": "noun",
	"маліцка": "adjective",
	"молдова": "noun",
	"моркова": "noun",
	"пажина": "adjective",
	"перевернихата": "noun",
	"пилева": "adjective",
	"піддубня": "adjective",
	"постіва": "noun",
	"пуста": "adjective",
	"суботня": "adjective",
	"фадеева": "adjective",
	"ходаніцка": "adjective",
	"хохітва": "noun",
	"цибата": "adjective",
	"черноока": "adjective",
	"чкадуа": "noun",
	"чокена": "noun",
	"шепетина": "noun",
	"шербина": "noun",
	"яка": "adjective",
	"ятва": "noun",
	"безена": "noun",
	"безшкура": "adjective",
	"безязика": "adjective",
	"белая": "adjective",
	"берулава": "noun",
	"бузна": "noun",
	"бурсала": "noun",
	"бучаста": "adjective",
	"вчина": "noun",
	"гапона": "noun",
	"гернажа": "noun",
	"гордуна": "noun",
	"горсва": "noun",
	"горясва": "noun",
	"грицька": "noun",
	"двіжона": "noun",
	"задурня": "adjective",
	"заслона": "noun",
	"зачешигрива": "noun",
	"йона": "noun",
	"качна": "adjective",
	"козовіта": "noun",
	"криворота": "adjective",
	"кур'ята": "noun",
	"лозна": "adjective",
	"люлява": "noun",
	"лютая": "adjective",
	"матухна": "noun",
	"накутня": "adjective",
	"плохая": "adjective",
	"бухая": "adjective",
	"самотня": "adjective",
	"панібудьласка": "noun"
};

exports.default = incorrectPredictionsCache;
