/**
 * @file JavaScript library for declension of Ukrainian anthroponyms
 * @module shevchenko
 * @version 3.1.4
 * @author Oleksandr Tolochko <shevchenko-js@tooleks.com>
 * @license MIT
 * @copyright 2017-2025 Oleksandr Tolochko <shevchenko-js@tooleks.com>
 * @see {@link git+https://github.com/tooleks/shevchenko-js.git}
 */
'use strict';

var shevchenko = require('./shevchenko.js');
var inputValidation = require('./input-validation.js');
var grammaticalCase = require('./language/grammatical-case.js');
var grammaticalGender = require('./language/grammatical-gender.js');
var wordClass = require('./language/word-class.js');
var wordInflector = require('./word-declension/word-inflector.js');
var extension = require('./extension.js');



exports.detectGender = shevchenko.detectGender;
exports.inAblative = shevchenko.inAblative;
exports.inAccusative = shevchenko.inAccusative;
exports.inDative = shevchenko.inDative;
exports.inGenitive = shevchenko.inGenitive;
exports.inLocative = shevchenko.inLocative;
exports.inNominative = shevchenko.inNominative;
exports.inVocative = shevchenko.inVocative;
exports.InputValidationError = inputValidation.InputValidationError;
Object.defineProperty(exports, "GrammaticalCase", {
	enumerable: true,
	get: function () { return grammaticalCase.GrammaticalCase; }
});
Object.defineProperty(exports, "GrammaticalGender", {
	enumerable: true,
	get: function () { return grammaticalGender.GrammaticalGender; }
});
Object.defineProperty(exports, "WordClass", {
	enumerable: true,
	get: function () { return wordClass.WordClass; }
});
exports.WordInflector = wordInflector.WordInflector;
exports.registerExtension = extension.registerExtension;
