/**
 * @file JavaScript library for declension of Ukrainian anthroponyms
 * @module shevchenko
 * @version 3.1.4
 * @author Oleksandr Tolochko <shevchenko-js@tooleks.com>
 * @license MIT
 * @copyright 2017-2025 Oleksandr Tolochko <shevchenko-js@tooleks.com>
 * @see {@link git+https://github.com/tooleks/shevchenko-js.git}
 */
import { wordInflector } from '../word-declension/bootstrap.js';
import { AnthroponymInflector } from './anthroponym-inflector.js';
import { FamilyNameClassifier } from './family-name-classifier/family-name-classifer.js';
import { ModelBundleLoader } from './family-name-classifier/model-bundle-loader.js';
import { FamilyNameInflector } from './family-name-inflector.js';
import { GivenNameInflector } from './given-name-inflector.js';
import { PatronymicNameInflector } from './patronymic-name-inflector.js';

const givenNameInflector = new GivenNameInflector(wordInflector);
const patronymicNameInflector = new PatronymicNameInflector(wordInflector);
const familyNameClassifier = new FamilyNameClassifier(new ModelBundleLoader());
const familyNameInflector = new FamilyNameInflector(wordInflector, familyNameClassifier);
const anthroponymInflector = new AnthroponymInflector(givenNameInflector, patronymicNameInflector, familyNameInflector);

export { anthroponymInflector };
